@@ -3,10 +3,12 @@ use strict;
 use warnings;
 use base qw/Net::CIDR::MobileJP::Scraper::Plugin/;
 
+sub url { return 'http://developers.softbankmobile.co.jp/dp/tech_svc/web/ip.php'; }
+
 sub run {
     my ($self, ) = @_;
 
-    my $url = 'http://developers.softbankmobile.co.jp/dp/tech_svc/web/ip.php';
+    my $url = $self->url;
     my $content = $self->get($url);
 
     my @result;
